tlslite.errors.TLSClosedConnectionError

Package tlslite :: Module errors :: Class TLSClosedConnectionError |
[hide private]
[frames] | no frames]

# Class TLSClosedConnectionError

source code

                              object --+
                                       |
                exceptions.BaseException --+
                                           |
                        exceptions.Exception --+
                                               |
                                        TLSError --+
                                                   |
                  object --+                       |
                           |                       |
    exceptions.BaseException --+                   |
                               |                   |
            exceptions.Exception --+               |
                                   |               |
            exceptions.StandardError --+           |
                                       |           |
             exceptions.EnvironmentError --+       |
                                           |       |
                          exceptions.IOError --+   |
                                               |   |
                                    socket.error --+
                                                   |
                                                  TLSClosedConnectionError

An attempt was made to use the connection after it was closed.

Instance Methods | [hide private]
Inherited from `TLSError`: `__str__` Inherited from `exceptions.IOError`: `__init__`, `__new__` Inherited from `exceptions.EnvironmentError`: `__reduce__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.EnvironmentError`: `errno`, `filename`, `strerror` Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`